<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AddClock</name>
    <message>
        <source>Add Log Clock</source>
        <translation type="obsolete">Neue Loguhr hinzufügen</translation>
    </message>
    <message>
        <source>&amp;New Clock Name:</source>
        <translation>&amp;Name der neuen Uhr:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Add Clock</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddEvent</name>
    <message>
        <source>Add Log Event</source>
        <translation>Log Event hinzufügen</translation>
    </message>
    <message>
        <source>&amp;New Event Name:</source>
        <translation>&amp;Neuer Eventname:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
</context>
<context>
    <name>ClockListView</name>
    <message>
        <source>Edit Event</source>
        <translation>Event editieren</translation>
    </message>
</context>
<context>
    <name>EditClock</name>
    <message>
        <source>Edit Clock:</source>
        <translation type="obsolete">Uhr editieren:</translation>
    </message>
    <message>
        <source>Code:</source>
        <translation>Code:</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Ende</translation>
    </message>
    <message>
        <source>Event</source>
        <translation>Event</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Länge</translation>
    </message>
    <message>
        <source>Count</source>
        <translation>Zähler</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Hinzufügen</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editieren</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <source>Scheduler
Rules</source>
        <translation>Scheduler
Regeln</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Speichern &amp;Als</translation>
    </message>
    <message>
        <source>&amp;Services
List</source>
        <translation>&amp;Services
Liste</translation>
    </message>
    <message>
        <source>Colo&amp;r</source>
        <translation>Fa&amp;rbe</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Are you sure you want to
delete</source>
        <translation type="obsolete">Löschen von</translation>
    </message>
    <message>
        <source>Delete Event</source>
        <translation>Event Löschen</translation>
    </message>
    <message>
        <source>Clock Modified</source>
        <translation>Uhr modifiziert</translation>
    </message>
    <message>
        <source>The clock has been modified.
Do you want to save?</source>
        <translation>Die Uhr wurde modifiziert.
Wollen Sie sie speichern?</translation>
    </message>
    <message>
        <source>Missing Clock Code</source>
        <translation>Uhr Code fehlt</translation>
    </message>
    <message>
        <source>You must specify a clock code!</source>
        <translation>Sie müssen einen Uhr-Code eingeben!</translation>
    </message>
    <message>
        <source>Code Exists</source>
        <translation>Code existiert</translation>
    </message>
    <message>
        <source>The clock code is already in use!</source>
        <translation>Der Uhrcode wird bereits verwendet!</translation>
    </message>
    <message>
        <source>Clock Exists</source>
        <translation>Uhr existiert</translation>
    </message>
    <message>
        <source>Clock already exists!  Overwrite?</source>
        <translation>Uhr existiert bereits! Überschreiben?</translation>
    </message>
    <message>
        <source>--- End of clock ---</source>
        <translation type="obsolete">--- Ende der Uhr ---</translation>
    </message>
    <message>
        <source>Invalid Code</source>
        <translation>Ungültiger Code</translation>
    </message>
    <message>
        <source>You must provide a clock code!</source>
        <translation>Sie müssen einen Uhrcode angeben!</translation>
    </message>
    <message>
        <source>Duplicate Code</source>
        <translation>Doppelter Code</translation>
    </message>
    <message>
        <source>That code is already in use!</source>
        <translation>Dieser Code wird bereits verwendet!</translation>
    </message>
    <message>
        <source>Remarks</source>
        <translation type="obsolete">Bemerkungen</translation>
    </message>
    <message>
        <source>&amp;Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Clock</source>
        <translation type="unfinished">Uhr editieren</translation>
    </message>
    <message>
        <source>Are you sure you want to delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>That event does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>USER NOTES</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trans</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditEvent</name>
    <message>
        <source>Editing Event</source>
        <translation>Event editieren</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Audio Only</source>
        <translation>Nur Audio</translation>
    </message>
    <message>
        <source>Macros Only</source>
        <translation>Nur Makros</translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="obsolete">CART</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="obsolete">GRUPPE</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="obsolete">LÄNGE</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="obsolete">TITEL</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="obsolete">KÜNSTLER</translation>
    </message>
    <message>
        <source>START</source>
        <translation type="obsolete">START</translation>
    </message>
    <message>
        <source>END</source>
        <translation type="obsolete">ENDE</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="obsolete">TYP</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>ALLE</translation>
    </message>
    <message>
        <source>PRE-POSITION LOG</source>
        <translation>VOR-POSTIONSLOG</translation>
    </message>
    <message>
        <source>Cue to this event</source>
        <translation>Cue zu diesem Event</translation>
    </message>
    <message>
        <source>before scheduled start.  (First cart will have a STOP transition.)</source>
        <translation>vor dem geplanten Start. (Der erste Cart wird einen STOP-Übergang haben.)</translation>
    </message>
    <message>
        <source>TIMED START</source>
        <translation>FESTER START</translation>
    </message>
    <message>
        <source>Use hard start time</source>
        <translation>Harte Startzeit verwenden</translation>
    </message>
    <message>
        <source>Make Post Point</source>
        <translation type="obsolete">Post Point machen</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>Aktion wenn vorheriges Event noch läuft</translation>
    </message>
    <message>
        <source>Start immediately</source>
        <translation>Sofort starten</translation>
    </message>
    <message>
        <source>Make next</source>
        <translation>Als Nächstes</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Warte bis zu</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Abspielen</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Übergang</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Transition if previous event ends before start time:</source>
        <translation type="obsolete">Übergang wenn vorheriges Event vor der Startzeit endet:</translation>
    </message>
    <message>
        <source>ENFORCING LENGTH</source>
        <translation>ERZWUNGENE LÄNGE</translation>
    </message>
    <message>
        <source>Use AutoFill</source>
        <translation>AutoFill verwenden</translation>
    </message>
    <message>
        <source>Warn if fill is over or under</source>
        <translation>Warnen, wenn AutoFill mehr oder weniger</translation>
    </message>
    <message>
        <source>by at least</source>
        <translation>als mindestens</translation>
    </message>
    <message>
        <source>Use Timescaling</source>
        <translation>Verwende Zeitskalierung</translation>
    </message>
    <message>
        <source>TRANSITION</source>
        <translation type="obsolete">ÜBERGANG</translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation type="obsolete">ZÄHLER</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <source>From Traffic</source>
        <translation>Von Traffic</translation>
    </message>
    <message>
        <source>From Music</source>
        <translation>Von Musik</translation>
    </message>
    <message>
        <source>Select from:</source>
        <translation>Wähle aus:</translation>
    </message>
    <message>
        <source>Title Separation</source>
        <translation>Titelabstand</translation>
    </message>
    <message>
        <source>Must have code</source>
        <translation>Erzwinge Code</translation>
    </message>
    <message>
        <source>Import carts scheduled</source>
        <translation>Import-Carts geplant</translation>
    </message>
    <message>
        <source>prior to the start of this event.</source>
        <translation>vor dem Start dieses Events.</translation>
    </message>
    <message>
        <source>after the end of this event.</source>
        <translation>nach dem Start dieses Events.</translation>
    </message>
    <message>
        <source>First cart has a</source>
        <translation>erster Cart hat einen</translation>
    </message>
    <message>
        <source>Imported carts have a</source>
        <translation type="unfinished">Importierte Carts haben eine</translation>
    </message>
    <message>
        <source>transition.</source>
        <translation type="unfinished">Übergang.</translation>
    </message>
    <message>
        <source>Import inline traffic with the</source>
        <translation type="obsolete">Importiere Inline-Traffic mit dem</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[keine]</translation>
    </message>
    <message>
        <source>event.</source>
        <translation type="obsolete">Event.</translation>
    </message>
    <message>
        <source>POST-IMPORT CARTS</source>
        <translation>CARTS NACH DEM IMPORT</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Speichern &amp;Als</translation>
    </message>
    <message>
        <source>&amp;Services
List</source>
        <translation>&amp;Services
Liste</translation>
    </message>
    <message>
        <source>C&amp;olor</source>
        <translation>&amp;Farbe</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation>RDLogManager</translation>
    </message>
    <message>
        <source>Event already exists!
Do you want to overwrite it?</source>
        <translation>Event existiert bereits!
Wollen Sie es überschreiben?</translation>
    </message>
    <message>
        <source>Edit Event</source>
        <translation>Event editieren</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Macro</source>
        <translation>Makro</translation>
    </message>
    <message>
        <source>Cue</source>
        <translation type="obsolete">CUE</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="obsolete">ÜBERGANG</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="obsolete">STOP</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="obsolete">PLAY</translation>
    </message>
    <message>
        <source>, Timed(Start)</source>
        <translation type="obsolete">, Fest (Start)</translation>
    </message>
    <message>
        <source>, Timed(MakeNext)</source>
        <translation type="obsolete">, Zeitstart(AlsNächstes)</translation>
    </message>
    <message>
        <source>Timed(Wait</source>
        <translation type="obsolete">Zeitstart(Warte</translation>
    </message>
    <message>
        <source>, Post</source>
        <translation type="obsolete">, Nach</translation>
    </message>
    <message>
        <source>, Fill</source>
        <translation type="obsolete">, Füllen</translation>
    </message>
    <message>
        <source>, Scale</source>
        <translation type="obsolete">, Scale</translation>
    </message>
    <message>
        <source>, Traffic</source>
        <translation type="obsolete">, Traffic</translation>
    </message>
    <message>
        <source>, Music</source>
        <translation type="obsolete">, Musik</translation>
    </message>
    <message>
        <source>, Scheduler</source>
        <translation type="obsolete">, Scheduler</translation>
    </message>
    <message>
        <source>, Inline Traffic</source>
        <translation type="obsolete">, Inline Traffic</translation>
    </message>
    <message>
        <source>REMARKS</source>
        <translation type="obsolete">BEMERKUNGEN</translation>
    </message>
    <message>
        <source>Len:</source>
        <translation>Länge:</translation>
    </message>
    <message>
        <source>PRE-IMPORT CARTS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IMPORT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>and code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished">Länge</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished">Start</translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished">Ende</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Count</source>
        <translation type="unfinished">Zähler</translation>
    </message>
    <message>
        <source>Artist Separation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRANSITIONS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CART STACK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import inline traffic event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>USER NOTES</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditEventLine</name>
    <message>
        <source>Edit Event Assignment</source>
        <translation>Event-Zuordnung editieren</translation>
    </message>
    <message>
        <source>Event:</source>
        <translation>Event:</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Startzeit:</translation>
    </message>
    <message>
        <source>End Time:</source>
        <translation>Endzeit:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Invalid Event</source>
        <translation>Ungültiges Event</translation>
    </message>
    <message>
        <source>The event end time cannot be earlier than the start time.</source>
        <translation>Die Endzeit des Events kann nicht vor der Startzeit liegen.</translation>
    </message>
    <message>
        <source>No Such Event</source>
        <translation>Kein solches Event</translation>
    </message>
    <message>
        <source>There is no such event.</source>
        <translation>Es gibt kein solches Event.</translation>
    </message>
    <message>
        <source>This event overlaps with an
already existing event.</source>
        <translation>Dieses Event überschneidet sich mit
einem bereits existierendem Event.</translation>
    </message>
</context>
<context>
    <name>EditGrid</name>
    <message>
        <source>Edit Grid:</source>
        <translation type="obsolete">Grid editieren:</translation>
    </message>
    <message>
        <source>Edit Clock</source>
        <translation>Uhr editieren</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schliessen</translation>
    </message>
    <message>
        <source>Clear Hour</source>
        <translation>Stunde löschen</translation>
    </message>
    <message>
        <source>Change
&amp;All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Clocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to update ALL clocks in the grid?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This operation cannot be undone!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Grid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditNote</name>
    <message>
        <source>Edit Log Note</source>
        <translation>Log Notiz editieren</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
</context>
<context>
    <name>EditPerms</name>
    <message>
        <source>Service Associations</source>
        <translation>Service-Zuordnungen</translation>
    </message>
    <message>
        <source>Available Services</source>
        <translation>Verfügbare Services</translation>
    </message>
    <message>
        <source>Enabled Services</source>
        <translation>Verwendete Services</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
</context>
<context>
    <name>EditSchedCodeRules</name>
    <message>
        <source>Edit Rules for Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Code:</source>
        <translation type="unfinished">Code:</translation>
    </message>
    <message>
        <source>Max. in a row:</source>
        <translation type="unfinished">Max. hintereinander:</translation>
    </message>
    <message>
        <source>Min. wait:</source>
        <translation type="unfinished">Mindestwartezeit:</translation>
    </message>
    <message>
        <source>Do not schedule after:</source>
        <translation type="unfinished">Plane nicht nach:</translation>
    </message>
    <message>
        <source>Or after:</source>
        <translation type="unfinished">oder nach:</translation>
    </message>
</context>
<context>
    <name>EditSchedRules</name>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editieren</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Importieren</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>CODE</source>
        <translation>CODE</translation>
    </message>
    <message>
        <source>MAX. IN A ROW</source>
        <translation>MAX HINTEREINANDER</translation>
    </message>
    <message>
        <source>MIN. WAIT</source>
        <translation>MIN WARTEZEIT</translation>
    </message>
    <message>
        <source>DO NOT SCHEDULE AFTER</source>
        <translation>SPIELE NICHT NACH</translation>
    </message>
    <message>
        <source>OR AFTER</source>
        <translation>ODER NACH</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>BESCHREIBUNG</translation>
    </message>
    <message>
        <source>Scheduler Codes:</source>
        <translation>Scheduler Codes:</translation>
    </message>
    <message>
        <source>Rules Modified</source>
        <translation>Regeln modifiziert</translation>
    </message>
    <message>
        <source>The rules have been modified.
Do you want to save?</source>
        <translation>Die Regeln wurden geändert.
Wollen Sie sie speichern?</translation>
    </message>
    <message>
        <source>Scheduler Rules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist Separation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Rules from Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">Keine</translation>
    </message>
    <message>
        <source>(This setting is deprecated and has been moved to events)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditTrack</name>
    <message>
        <source>Edit Voice Track Marker</source>
        <translation>Voice Track Marker editieren</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
</context>
<context>
    <name>GenerateLog</name>
    <message>
        <source>Generating Log...</source>
        <translation>Generiere Log...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Service:</source>
        <translation>Service:</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Datum:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>Au&amp;swählen</translation>
    </message>
    <message>
        <source>&amp;Create New Log</source>
        <translation>&amp;Neues Log erstellen</translation>
    </message>
    <message>
        <source>Merge &amp;Music</source>
        <translation>&amp;Musik zusammenführen</translation>
    </message>
    <message>
        <source>Merge &amp;Traffic</source>
        <translation>&amp;Traffic zusammenführen</translation>
    </message>
    <message>
        <source>Import Data</source>
        <translation>Daten importieren</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Verfügbar</translation>
    </message>
    <message>
        <source>Merged</source>
        <translation>Verbunden</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Schliessen</translation>
    </message>
    <message>
        <source>The log for</source>
        <translation>Das Log für</translation>
    </message>
    <message>
        <source>already exists.  Recreating it
will remove any merged Music or Traffic events.

Recreate?</source>
        <translation type="obsolete">existiert bereits. Es erneut zu erstellen
wird alle verbundene Musik oder Traffic Events entfernen.

Neu erstellen?</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation>Log existiert</translation>
    </message>
    <message>
        <source>This will also delete the</source>
        <translation>Dies löscht ebenfalls die</translation>
    </message>
    <message>
        <source>voice tracks associated with this log.
Continue?</source>
        <translation type="obsolete">Voice Tracks die mit diesem Log verbunden sind.
Fortfahren?</translation>
    </message>
    <message>
        <source>Tracks Exist</source>
        <translation>Track existiert</translation>
    </message>
    <message>
        <source>No Errors</source>
        <translation type="unfinished">Keine Fehler</translation>
    </message>
    <message>
        <source>No exceptions found.</source>
        <translation type="obsolete">Keine Fehler gefunden.</translation>
    </message>
    <message>
        <source>already contains merged music and/or traffic data.
Remerging it will remove this data.  Remerge?</source>
        <translation type="obsolete">enthält bereits eingebundene Musik- und/oder Trafficdaten.
Erneutes einbinden wird diese löschen. Erneut einbinden?</translation>
    </message>
    <message>
        <source>Music Exists</source>
        <translation>Musik existiert</translation>
    </message>
    <message>
        <source>already contains merged traffic data.  Remerging it
will remove this data.  Remerge?</source>
        <translation type="obsolete">enthält bereits verbundene Trafficdaten. Erneutes
Einbinden wird diese entfernen. Fortfahren?</translation>
    </message>
    <message>
        <source>Traffic Exists</source>
        <translation>Traffix existiert</translation>
    </message>
    <message>
        <source>Generate Log - User: </source>
        <translation type="obsolete">Generiere Log - User: </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to generate log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to clear traffic links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to clear music links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to link music log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to link traffic log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generate Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>already exists.  Recreating it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>will remove any merged Music or Traffic events.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recreate?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>voice tracks associated with this log.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>already contains merged music and/or traffic data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remerging it will remove this data.  Remerge?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>already contains merged traffic data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cannot be relinked.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No broken rules or validation exceptions found.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportListView</name>
    <message>
        <source>Insert Log Note</source>
        <translation>Log-Notiz einfügen</translation>
    </message>
    <message>
        <source>Edit Log Note</source>
        <translation>Log Notiz editieren</translation>
    </message>
    <message>
        <source>Insert Voice Track</source>
        <translation>Voice Track einfügen</translation>
    </message>
    <message>
        <source>Edit Voice Track</source>
        <translation>Voice Track editieren</translation>
    </message>
    <message>
        <source>Set PLAY Transition</source>
        <translation type="obsolete">PLAY-Übergang setzen</translation>
    </message>
    <message>
        <source>Set SEGUE Transition</source>
        <translation type="obsolete">SEGUE-Übergang setzen</translation>
    </message>
    <message>
        <source>Set STOP Transition</source>
        <translation type="obsolete">STOP-Übergang setzen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>löschen</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Marker</translation>
    </message>
    <message>
        <source>[Log Note]</source>
        <translation>[log notiz]</translation>
    </message>
    <message>
        <source>Track</source>
        <translation>Track</translation>
    </message>
    <message>
        <source>[Voice Track]</source>
        <translation>[Voice Track]</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>PLAY</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>ÜBERGANG</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>STOP</translation>
    </message>
    <message>
        <source>PLAY Transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SEGUE Transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STOP Transition</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListClocks</name>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Code</source>
        <translation>Code</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Hinzufügen</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editieren</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Umbenennen</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Schliessen</translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>ALLE</translation>
    </message>
    <message>
        <source>NONE</source>
        <translation>KEINE</translation>
    </message>
    <message>
        <source>Clock Exists</source>
        <translation>Uhr existiert</translation>
    </message>
    <message>
        <source>An clock with that name already exists!</source>
        <translation>Eine Uhr mit diesem Namen existiert bereits!</translation>
    </message>
    <message>
        <source>Are you sure you want to
delete</source>
        <translation type="obsolete">Löschen von</translation>
    </message>
    <message>
        <source>Delete Clock</source>
        <translation>Uhr löschen</translation>
    </message>
    <message>
        <source>is in use in the following grid(s):</source>
        <translation type="obsolete">wird von folgenden grid(s) verwendet:</translation>
    </message>
    <message>
        <source>Do you still want to delete it?</source>
        <translation>Wollen Sie immernoch löschen?</translation>
    </message>
    <message>
        <source>Clock In Use</source>
        <translation>Uhr in Verwendung</translation>
    </message>
    <message>
        <source>Log Clocks - User: </source>
        <translation type="obsolete">Log-Uhrenbenutzer: </translation>
    </message>
    <message>
        <source>Log Clocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is in use in the following grid(s)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListEvents</name>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Eigenschaften</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="obsolete">Farbe</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Hinzufügen</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editieren</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Umbenennen</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Ok</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>ALLE</translation>
    </message>
    <message>
        <source>NONE</source>
        <translation>KEINE</translation>
    </message>
    <message>
        <source>Event Exists</source>
        <translation>Event existiert</translation>
    </message>
    <message>
        <source>An event with that name already exists!</source>
        <translation>Ein Event mit diesem Namen existiert bereits!</translation>
    </message>
    <message>
        <source>Are you sure you want to
delete</source>
        <translation type="obsolete">Löschen von</translation>
    </message>
    <message>
        <source>Delete Event</source>
        <translation>Event Löschen</translation>
    </message>
    <message>
        <source>is in use in the following clocks:</source>
        <translation type="obsolete">wird von folgenden Uhren verwendet:</translation>
    </message>
    <message>
        <source>Do you still want to delete it?</source>
        <translation>Wollen Sie immernoch löschen?</translation>
    </message>
    <message>
        <source>Event In Use</source>
        <translation>Event in Verwendung</translation>
    </message>
    <message>
        <source>Log Events - User: </source>
        <translation type="obsolete">Log-Events-Benutzer: </translation>
    </message>
    <message>
        <source>Log Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is in use in the following clocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trans</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListGrids</name>
    <message>
        <source>Log Grids</source>
        <translation>Log Grids</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editieren</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Schliessen</translation>
    </message>
</context>
<context>
    <name>ListSvcs</name>
    <message>
        <source>Rivendell Services</source>
        <translation>Rivendell Services</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation type="obsolete">SERVICE</translation>
    </message>
    <message>
        <source>OLDEST REPORT</source>
        <translation type="obsolete">ÄLTESTER REPORT</translation>
    </message>
    <message>
        <source>&amp;Generate
Reports</source>
        <translation>Reports
&amp;Generieren</translation>
    </message>
    <message>
        <source>&amp;Purge
Data</source>
        <translation>Daten
&amp;Löschen</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Schliessen</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[keine]</translation>
    </message>
    <message>
        <source>Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Oldest Report</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="obsolete">Kann nicht verbinden</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation>RDLogManager</translation>
    </message>
    <message>
        <source>Select an operation:</source>
        <translation>Wählen Sie eine Operation:</translation>
    </message>
    <message>
        <source>Edit &amp;Events</source>
        <translation>&amp;Events editieren</translation>
    </message>
    <message>
        <source>Edit C&amp;locks</source>
        <translation>&amp;Uhren editieren</translation>
    </message>
    <message>
        <source>Edit G&amp;rids</source>
        <translation>&amp;Grids editieren</translation>
    </message>
    <message>
        <source>&amp;Generate Logs</source>
        <translation>Logs &amp;Generieren</translation>
    </message>
    <message>
        <source>Manage &amp;Reports</source>
        <translation>&amp;Reporte managen</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schliessen</translation>
    </message>
    <message>
        <source>RDLogManager - User: </source>
        <translation type="obsolete">RDLogManager - Benutzer: </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PickReportDates</name>
    <message>
        <source>Select Report Dates</source>
        <translation>Reportdaten auswählen</translation>
    </message>
    <message>
        <source>&amp;Report:</source>
        <translation>&amp;Report:</translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation>&amp;Startdatum:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>Au&amp;swählen</translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation>&amp;Enddatum:</translation>
    </message>
    <message>
        <source>&amp;Generate
Report</source>
        <translation>&amp;Generiere
Report</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Schliessen</translation>
    </message>
    <message>
        <source>Invalid Date Range</source>
        <translation>Ungültiger Datenbereich</translation>
    </message>
    <message>
        <source>The end date cannot be earlier than the start date!</source>
        <translation>Das Enddatum kann nicht vor dem Startdatum liegen!</translation>
    </message>
    <message>
        <source>This report type cannot span multiple dates!</source>
        <translation>Dieser Report kann nicht mehrere Tage umfassen!</translation>
    </message>
    <message>
        <source>This report type cannot span multiple months!</source>
        <translation>Dieser Report kann nicht mehrere Monate einschliessen!</translation>
    </message>
    <message>
        <source>Report Complete</source>
        <translation type="obsolete">Report komplett</translation>
    </message>
    <message>
        <source>Report complete!</source>
        <translation type="obsolete">Report komplett!</translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open report file at</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The report file already exists.  Overwrite?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameItem</name>
    <message>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Name Conflict</source>
        <translation>Namenskonflikt</translation>
    </message>
    <message>
        <source>That name already exists!</source>
        <translation>Dieser Name existiert bereits!</translation>
    </message>
</context>
<context>
    <name>SvcRec</name>
    <message>
        <source>Mo</source>
        <translation>Mo</translation>
    </message>
    <message>
        <source>Tu</source>
        <translation>Di</translation>
    </message>
    <message>
        <source>We</source>
        <translation>Mi</translation>
    </message>
    <message>
        <source>Th</source>
        <translation>Do</translation>
    </message>
    <message>
        <source>Fr</source>
        <translation>Fr</translation>
    </message>
    <message>
        <source>Sa</source>
        <translation>Sa</translation>
    </message>
    <message>
        <source>Su</source>
        <translation>So</translation>
    </message>
</context>
<context>
    <name>SvcRecDialog</name>
    <message>
        <source>Report Data</source>
        <translation>Reportdaten</translation>
    </message>
    <message>
        <source>&amp;Purge
Data</source>
        <translation>Daten
&amp;Löschen</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schliessen</translation>
    </message>
    <message>
        <source>Delete Report Data</source>
        <translation>Reportdaten löschen</translation>
    </message>
    <message>
        <source>Are you sure you want to delete report data for</source>
        <translation>Reportdaten wirklich löschen für</translation>
    </message>
</context>
<context>
    <name>editSchedCodeRules</name>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Code:</source>
        <translation type="obsolete">Code:</translation>
    </message>
    <message>
        <source>Max. in a row:</source>
        <translation type="obsolete">Max. hintereinander:</translation>
    </message>
    <message>
        <source>Min. wait:</source>
        <translation type="obsolete">Mindestwartezeit:</translation>
    </message>
    <message>
        <source>Do not schedule after:</source>
        <translation type="obsolete">Plane nicht nach:</translation>
    </message>
    <message>
        <source>Or after:</source>
        <translation type="obsolete">oder nach:</translation>
    </message>
</context>
</TS>
